VerificationRequirements

Enum VerificationRequirements 

pub enum VerificationRequirements {
    VerifyClaims {
        acceptable_algorithms: Vec<String>,
        acceptable_issuers: Option<Vec<Issuer>>,
        acceptable_audiences: Option<Vec<Audience>>,
        acceptable_subject: Option<String>,
    },
    VerifySignatureOnly {
        acceptable_algorithms: Vec<String>,
    },
}
Verification requirements to use when verifying a signed JWT.

Variants



VerifyClaims

Verify the signature and provided claims for the JWT.

Fields

acceptable_algorithms: Vec<String>

Acceptable signing algorithms.

acceptable_issuers: Option<Vec<Issuer>>

Acceptable issuers. None indicates any issuer is acceptable.

acceptable_audiences: Option<Vec<Audience>>

Acceptable audiences. None indicates any audience is acceptable.

acceptable_subject: Option<String>

Acceptable subject. None indicates any subject is acceptable.



VerifySignatureOnly

Only verify the signature of the JWT but do not verify any claims.

Fields

acceptable_algorithms: Vec<String>

Acceptable signing algorithms.

Implementations

Source

impl VerificationRequirements

pub fn acceptable_algorithms(&self) -> &[String]

Acceptable signing algorithms.