pub trait SigningKeyManager: AttenuationKeyGenerator<Self::PublicAttenuationKey, Self::PrivateAttenuationKey> + Clone {
type JWK: Serialize;
type PublicAttenuationKey: PublicKey;
type PrivateAttenuationKey: PrivateKey;
type PrivateRootKey: PrivateKey;
type Claims: Serialize;
// Required method
fn jwk_for_public_attenuation_key(
public_attenuation_key: &Self::PublicAttenuationKey,
) -> Self::JWK;
}Expand description
Trait handling signing and key generation for crate::sign::AttenuableJWT.
Required Associated Types
Sourcetype JWK: Serialize
type JWK: Serialize
Type of the JWK for the Self::PublicAttenuationKey.
Sourcetype PublicAttenuationKey: PublicKey
type PublicAttenuationKey: PublicKey
Type of the public key for the attenuation keys.
Sourcetype PrivateAttenuationKey: PrivateKey
type PrivateAttenuationKey: PrivateKey
Type of the private key for the attenuation keys.
Sourcetype PrivateRootKey: PrivateKey
type PrivateRootKey: PrivateKey
Type of the private key for the root JWT.
Required Methods
Sourcefn jwk_for_public_attenuation_key(
public_attenuation_key: &Self::PublicAttenuationKey,
) -> Self::JWK
fn jwk_for_public_attenuation_key( public_attenuation_key: &Self::PublicAttenuationKey, ) -> Self::JWK
Return a JWK representing the provided public attenuation key.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.